# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: rule_installation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'rule_installation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17rule_installation.proto\x12\x11rule_installation\"y\n\x13InstallRulesRequest\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\x12.\n\x05rules\x18\x02 \x03(\x0b\x32\x1f.rule_installation.RuleInstance\x12\x11\n\tconfig_id\x18\x03 \x01(\t\x12\r\n\x05owner\x18\x04 \x01(\t\"\xf1\x01\n\x14InstallRulesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x17\n\x0frules_installed\x18\x03 \x01(\x05\x12Q\n\x0erules_by_layer\x18\x04 \x03(\x0b\x32\x39.rule_installation.InstallRulesResponse.RulesByLayerEntry\x12\x16\n\x0e\x62ridge_version\x18\x05 \x01(\x03\x1a\x33\n\x11RulesByLayerEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"+\n\x17RemoveAgentRulesRequest\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"S\n\x18RemoveAgentRulesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrules_removed\x18\x03 \x01(\x05\"\x15\n\x13GetRuleStatsRequest\"\xc5\x01\n\x14GetRuleStatsResponse\x12\x16\n\x0e\x62ridge_version\x18\x01 \x01(\x03\x12\x14\n\x0ctotal_tables\x18\x02 \x01(\x05\x12\x13\n\x0btotal_rules\x18\x03 \x01(\x05\x12\x1a\n\x12total_global_rules\x18\x04 \x01(\x05\x12\x1a\n\x12total_scoped_rules\x18\x05 \x01(\x05\x12\x32\n\x0btable_stats\x18\x06 \x03(\x0b\x32\x1d.rule_installation.TableStats\"\x82\x01\n\nTableStats\x12\x11\n\tfamily_id\x18\x01 \x01(\t\x12\x10\n\x08layer_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x03\x12\x12\n\nrule_count\x18\x04 \x01(\x05\x12\x14\n\x0cglobal_count\x18\x05 \x01(\x05\x12\x14\n\x0cscoped_count\x18\x06 \x01(\x05\"\x1e\n\x0c\x41nchorVector\x12\x0e\n\x06values\x18\x01 \x03(\x02\"\xcc\x02\n\x12RuleAnchorsPayload\x12\x37\n\x0e\x61\x63tion_anchors\x18\x01 \x03(\x0b\x32\x1f.rule_installation.AnchorVector\x12\x14\n\x0c\x61\x63tion_count\x18\x02 \x01(\x05\x12\x39\n\x10resource_anchors\x18\x03 \x03(\x0b\x32\x1f.rule_installation.AnchorVector\x12\x16\n\x0eresource_count\x18\x04 \x01(\x05\x12\x35\n\x0c\x64\x61ta_anchors\x18\x05 \x03(\x0b\x32\x1f.rule_installation.AnchorVector\x12\x12\n\ndata_count\x18\x06 \x01(\x05\x12\x35\n\x0crisk_anchors\x18\x07 \x03(\x0b\x32\x1f.rule_installation.AnchorVector\x12\x12\n\nrisk_count\x18\x08 \x01(\x05\"\xd0\x02\n\x0cRuleInstance\x12\x0f\n\x07rule_id\x18\x01 \x01(\t\x12\x11\n\tfamily_id\x18\x02 \x01(\t\x12\r\n\x05layer\x18\x03 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x06 \x01(\x08\x12\x15\n\rcreated_at_ms\x18\x07 \x01(\x03\x12;\n\x06params\x18\x08 \x03(\x0b\x32+.rule_installation.RuleInstance.ParamsEntry\x12\x36\n\x07\x61nchors\x18\t \x01(\x0b\x32%.rule_installation.RuleAnchorsPayload\x1aL\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.rule_installation.ParamValue:\x02\x38\x01\"\xa5\x01\n\nParamValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x34\n\x0bstring_list\x18\x05 \x01(\x0b\x32\x1d.rule_installation.StringListH\x00\x42\x07\n\x05value\"\x1c\n\nStringList\x12\x0e\n\x06values\x18\x01 \x03(\t\"B\n\x0e\x45nforceRequest\x12\x19\n\x11intent_event_json\x18\x01 \x01(\t\x12\x15\n\rintent_vector\x18\x02 \x03(\x02\"\x8b\x01\n\x0f\x45nforceResponse\x12\x10\n\x08\x64\x65\x63ision\x18\x01 \x01(\x05\x12\x1a\n\x12slice_similarities\x18\x02 \x03(\x02\x12\x17\n\x0frules_evaluated\x18\x03 \x01(\x05\x12\x31\n\x08\x65vidence\x18\x04 \x03(\x0b\x32\x1f.rule_installation.RuleEvidence\"Z\n\x0cRuleEvidence\x12\x0f\n\x07rule_id\x18\x01 \x01(\t\x12\x11\n\trule_name\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x63ision\x18\x03 \x01(\x05\x12\x14\n\x0csimilarities\x18\x04 \x03(\x02\"\x9a\x02\n\x15QueryTelemetryRequest\x12\x15\n\x08\x61gent_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\ttenant_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x64\x65\x63ision\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x12\n\x05layer\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rstart_time_ms\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x18\n\x0b\x65nd_time_ms\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\r\n\x05limit\x18\x07 \x01(\x05\x12\x0e\n\x06offset\x18\x08 \x01(\x05\x42\x0b\n\t_agent_idB\x0c\n\n_tenant_idB\x0b\n\t_decisionB\x08\n\x06_layerB\x10\n\x0e_start_time_msB\x0e\n\x0c_end_time_ms\"m\n\x16QueryTelemetryResponse\x12>\n\x08sessions\x18\x01 \x03(\x0b\x32,.rule_installation.EnforcementSessionSummary\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xdd\x01\n\x19\x45nforcementSessionSummary\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\t\x12\r\n\x05layer\x18\x04 \x01(\t\x12\x14\n\x0ctimestamp_ms\x18\x05 \x01(\x03\x12\x16\n\x0e\x66inal_decision\x18\x06 \x01(\x05\x12\x1d\n\x15rules_evaluated_count\x18\x07 \x01(\x05\x12\x13\n\x0b\x64uration_us\x18\x08 \x01(\x03\x12\x16\n\x0eintent_summary\x18\t \x01(\t\"\'\n\x11GetSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"*\n\x12GetSessionResponse\x12\x14\n\x0csession_json\x18\x01 \x01(\t2\xce\x04\n\tDataPlane\x12_\n\x0cInstallRules\x12&.rule_installation.InstallRulesRequest\x1a\'.rule_installation.InstallRulesResponse\x12k\n\x10RemoveAgentRules\x12*.rule_installation.RemoveAgentRulesRequest\x1a+.rule_installation.RemoveAgentRulesResponse\x12_\n\x0cGetRuleStats\x12&.rule_installation.GetRuleStatsRequest\x1a\'.rule_installation.GetRuleStatsResponse\x12P\n\x07\x45nforce\x12!.rule_installation.EnforceRequest\x1a\".rule_installation.EnforceResponse\x12\x65\n\x0eQueryTelemetry\x12(.rule_installation.QueryTelemetryRequest\x1a).rule_installation.QueryTelemetryResponse\x12Y\n\nGetSession\x12$.rule_installation.GetSessionRequest\x1a%.rule_installation.GetSessionResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rule_installation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INSTALLRULESRESPONSE_RULESBYLAYERENTRY']._loaded_options = None
  _globals['_INSTALLRULESRESPONSE_RULESBYLAYERENTRY']._serialized_options = b'8\001'
  _globals['_RULEINSTANCE_PARAMSENTRY']._loaded_options = None
  _globals['_RULEINSTANCE_PARAMSENTRY']._serialized_options = b'8\001'
  _globals['_INSTALLRULESREQUEST']._serialized_start=46
  _globals['_INSTALLRULESREQUEST']._serialized_end=167
  _globals['_INSTALLRULESRESPONSE']._serialized_start=170
  _globals['_INSTALLRULESRESPONSE']._serialized_end=411
  _globals['_INSTALLRULESRESPONSE_RULESBYLAYERENTRY']._serialized_start=360
  _globals['_INSTALLRULESRESPONSE_RULESBYLAYERENTRY']._serialized_end=411
  _globals['_REMOVEAGENTRULESREQUEST']._serialized_start=413
  _globals['_REMOVEAGENTRULESREQUEST']._serialized_end=456
  _globals['_REMOVEAGENTRULESRESPONSE']._serialized_start=458
  _globals['_REMOVEAGENTRULESRESPONSE']._serialized_end=541
  _globals['_GETRULESTATSREQUEST']._serialized_start=543
  _globals['_GETRULESTATSREQUEST']._serialized_end=564
  _globals['_GETRULESTATSRESPONSE']._serialized_start=567
  _globals['_GETRULESTATSRESPONSE']._serialized_end=764
  _globals['_TABLESTATS']._serialized_start=767
  _globals['_TABLESTATS']._serialized_end=897
  _globals['_ANCHORVECTOR']._serialized_start=899
  _globals['_ANCHORVECTOR']._serialized_end=929
  _globals['_RULEANCHORSPAYLOAD']._serialized_start=932
  _globals['_RULEANCHORSPAYLOAD']._serialized_end=1264
  _globals['_RULEINSTANCE']._serialized_start=1267
  _globals['_RULEINSTANCE']._serialized_end=1603
  _globals['_RULEINSTANCE_PARAMSENTRY']._serialized_start=1527
  _globals['_RULEINSTANCE_PARAMSENTRY']._serialized_end=1603
  _globals['_PARAMVALUE']._serialized_start=1606
  _globals['_PARAMVALUE']._serialized_end=1771
  _globals['_STRINGLIST']._serialized_start=1773
  _globals['_STRINGLIST']._serialized_end=1801
  _globals['_ENFORCEREQUEST']._serialized_start=1803
  _globals['_ENFORCEREQUEST']._serialized_end=1869
  _globals['_ENFORCERESPONSE']._serialized_start=1872
  _globals['_ENFORCERESPONSE']._serialized_end=2011
  _globals['_RULEEVIDENCE']._serialized_start=2013
  _globals['_RULEEVIDENCE']._serialized_end=2103
  _globals['_QUERYTELEMETRYREQUEST']._serialized_start=2106
  _globals['_QUERYTELEMETRYREQUEST']._serialized_end=2388
  _globals['_QUERYTELEMETRYRESPONSE']._serialized_start=2390
  _globals['_QUERYTELEMETRYRESPONSE']._serialized_end=2499
  _globals['_ENFORCEMENTSESSIONSUMMARY']._serialized_start=2502
  _globals['_ENFORCEMENTSESSIONSUMMARY']._serialized_end=2723
  _globals['_GETSESSIONREQUEST']._serialized_start=2725
  _globals['_GETSESSIONREQUEST']._serialized_end=2764
  _globals['_GETSESSIONRESPONSE']._serialized_start=2766
  _globals['_GETSESSIONRESPONSE']._serialized_end=2808
  _globals['_DATAPLANE']._serialized_start=2811
  _globals['_DATAPLANE']._serialized_end=3401
# @@protoc_insertion_point(module_scope)
